@@ -934,6 +934,40 @@ cheese_camera_connect_effect_texture (CheeseCamera *camera, CheeseEffect *effect
   g_object_set (G_OBJECT (priv->effects_valve), "drop", FALSE, NULL);
 }
 
+/*
+ * cheese_camera_set_tags:
+ * @camera: a #CheeseCamera
+ *
+ * Set tags on the camerabin element, such as the stream creation time and the
+ * name of the application. Call this just before starting the capture process.
+ */
+static void
+cheese_camera_set_tags (CheeseCamera *camera)
+{
+  CheeseCameraPrivate *priv;
+  CheeseCameraDevice *device;
+  const gchar *device_name;
+  GstDateTime *datetime;
+  GstTagList *taglist;
+
+  device = cheese_camera_get_selected_device (camera);
+  device_name = cheese_camera_device_get_name (device);
+
+  datetime = gst_date_time_new_now_local_time();
+
+  taglist = gst_tag_list_new_full (
+      GST_TAG_APPLICATION_NAME, PACKAGE_STRING,
+      GST_TAG_DATE_TIME, datetime,
+      GST_TAG_DEVICE_MODEL, device_name,
+      GST_TAG_KEYWORDS, PACKAGE_NAME, NULL);
+
+  priv = camera->priv;
+  gst_tag_setter_merge_tags (GST_TAG_SETTER (priv->camerabin), taglist,
+        GST_TAG_MERGE_REPLACE);
+
+  gst_date_time_unref (datetime);
+}
+
 /**
  * cheese_camera_start_video_recording:
  * @camera: a #CheeseCamera
@@ -954,6 +988,7 @@ cheese_camera_start_video_recording (CheeseCamera *camera, const gchar *filename
   g_object_set (priv->camerabin, "mode", MODE_VIDEO, NULL);
   gst_element_set_state (priv->camerabin, GST_STATE_READY);
   g_object_set (priv->camerabin, "filename", filename, NULL);
+  cheese_camera_set_tags (camera);
   gst_element_set_state (priv->camerabin, GST_STATE_PLAYING);
   g_signal_emit_by_name (priv->camerabin, "capture-start", 0);
   priv->is_recording = TRUE;
@@ -1078,6 +1113,7 @@ cheese_camera_take_photo (CheeseCamera *camera, const gchar *filename)
   {
     g_object_set (priv->camerabin, "filename", priv->photo_filename, NULL);
     g_object_set (priv->camerabin, "mode", MODE_IMAGE, NULL);
+    cheese_camera_set_tags (camera);
     g_signal_emit_by_name (priv->camerabin, "capture-start", 0);
   }
   else
@@ -1706,3 +1742,55 @@ cheese_camera_set_balance_property (CheeseCamera *camera, const gchar *property,
 
   g_object_set (G_OBJECT (priv->video_balance), property, value, NULL);
 }
+
+/**
+ * cheese_camera_get_recorded_time:
+ * @camera: A #CheeseCamera
+ *
+ * Get a string representation of the playing time
+ * of the current video recording
+ *
+ * Returns: A string with the time representation.
+ */
+gchar *
+cheese_camera_get_recorded_time (CheeseCamera *camera)
+{
+  g_return_val_if_fail (CHEESE_IS_CAMERA (camera), NULL);
+
+  CheeseCameraPrivate *priv = camera->priv;
+  const gint TUNIT_60 = 60;
+  GstClock *clock;
+  GstClockTime base_time;
+  GstClockTime clock_time;
+  GstClockTimeDiff time_diff;
+  gint total_time;
+  gint hours;
+  gint minutes;
+  gint seconds;
+
+  base_time  = gst_element_get_base_time (priv->camerabin);
+  clock = gst_element_get_clock (priv->camerabin);
+  clock_time = gst_clock_get_time (clock);
+  gst_object_unref (clock);
+  /* In order to calculate the running time of the stream,
+   * it is necessary to substract the base_time from the
+   * clock_time. The result is expressed in nanoseconds.
+   * */
+  time_diff = GST_CLOCK_DIFF (base_time, clock_time);
+
+  // Substract seconds, minutes and hours.
+  total_time = GST_TIME_AS_SECONDS (time_diff);
+  seconds = total_time % TUNIT_60;
+  total_time = total_time - seconds;
+  minutes = (total_time % (TUNIT_60 * TUNIT_60)) / TUNIT_60;
+  total_time = total_time - (minutes * TUNIT_60);
+  hours = total_time / (TUNIT_60 * TUNIT_60);
+
+  /* Translators: This is a time format, like "09:05:02" for 9
+   * hours, 5 minutes, and 2 seconds. You may change ":" to
+   * the separator that your locale uses or use "%Id" instead
+   * of "%d" if your locale uses localized digits.
+   */
+  return g_strdup_printf (C_("time format", "%02i:%02i:%02i"),
+                          hours, minutes, seconds);
+}
